package net.reduls.igo;

public final class Morpheme {
    public final String surface;
    public final String feature;
    
    public Morpheme(String s, String f) {
	surface = s;
	feature = f;
    }
}